RSpec.shared_context 'kafka' do
  before(:each) do
    allow_any_instance_of(
      RoleManagement::Messages::RoleDocument
    ).to receive(:push).and_return(nil)
    allow_any_instance_of(
      RoleManagement::Messages::RoleBinding
    ).to receive(:push).and_return(nil)
  end
end

RSpec.shared_context 'request' do
  let(:request) {
    req = ::Platform::Contexts::Request.new
    req.client_ip = IPAddr.new('1.1.1.1')
    req.user_agent = 'Mozilla/4.0 WebTV/2.6 (compatible; MSIE 4.0)'
    req.current_customer = customer_id
    req.current_user = user_id
    req
  }
end

RSpec.shared_context 'role_management' do
  let(:id) { "1" }
  let(:customer_id) { "2017" }
  let(:user_id) { "3871" }
  let(:organization_id) { 17 }
  let(:user_group_id) { "1234" }

  let(:tenant_crn) { "crn:#{customer_id}:tenant/#{customer_id}" }
  let(:user_crn) { "crn:#{customer_id}:user/#{user_id}" }
  let(:current_org_crn) { ::Platform::CRNs::Organization.new(
    customer: customer_id.to_i,
    details: organization_id.to_s)
  }


  let!(:role_doc_ar) {
    FactoryBot.create(:role_document,
        name: "Fake Name",
        description: "Fake Description",
        customer_crn: tenant_crn,
        updated_by_crn: user_crn,
        system_defined: false,
        is_deleted: false,
        organization_id: organization_id
    )
  }

  let!(:role_binding_ar) {
    FactoryBot.create(:user_group_role_binding,
        customer_crn: tenant_crn.to_s,
        organization_crn: current_org_crn.to_s,
        created_by_crn: user_crn.to_s,
        updated_by_crn: user_crn.to_s,
        role_document: role_doc_ar
    )
  }

  let(:role_document) {
     role_doc = ::RoleManagement::Models::RoleDocument.new(
        id: role_doc_ar.id.to_s,
        name: role_doc_ar.name,
        description: role_doc_ar.description,
        organizationId: role_doc_ar.organization_id,
        system_defined: role_doc_ar.system_defined,
        restricted: role_doc_ar.restricted,
        created_at: role_doc_ar.created_at,
        updated_at: role_doc_ar.updated_at,
        created_by: role_doc_ar.created_by_crn,
        updated_by: role_doc_ar.updated_by_crn,
        permissions: [],
        user_group_role_bindings: role_doc_ar.user_group_role_bindings,
        metadata: ::RoleManagement::Models::Content::Metadata.new(
          shared: ::RoleManagement::Models::Content::SharedContentMetadata.new(
            enabled: true
          )
        )
     )
     role_doc
   }
  let(:role_binding) {
    role_binding = ::RoleManagement::Models::UserGroupRoleBinding.new(
        id: role_binding_ar.crn.to_s,
        customer_id: role_binding_ar.customer_crn,
        organization_id: role_binding_ar.organization_crn,
        organization_ids: [],
        role_document: role_document,
        user_group_id: role_binding_ar.user_group_crn,
        created_by_id: role_binding_ar.created_by_crn,
        updated_by_id: role_binding_ar.updated_by_crn,
        created_at: role_binding_ar.created_at,
        updated_at: role_binding_ar.updated_at
     )
     role_binding
  }
end
