require 'cht-lib-fabric/contexts/request'
require 'cht-lib-fabric/crns/tenant'

require 'role_management/models'
require 'role_management/graphql/schema'

require 'role_management/models/privileges'

RSpec.describe ::RoleManagement::GraphQL::Schema do
  include ::RoleManagement::Models::Privileges

  let(:customer_id) { 1 }
  let(:user_id) { 17 }
  let(:organization_id) { 17 }

  let(:request) do
    req = ::Platform::Contexts::Request.new
    req.client_ip = IPAddr.new('1.1.1.1')
    req.user_agent = 'Mozilla/4.0 WebTV/2.6 (compatible; MSIE 4.0)'
    req.current_customer = customer_id
    req.current_user = user_id
    req.current_organization = organization_id
    req
   end

   let!(:variables) { nil }

   before { Application.stub('clients.authorization', TrueAuthorizer.new) }
   after { Application.unstub('clients.authorization') }

   subject do
    RoleManagement::GraphQL::Schema.execute(
        graphql_query,
        context: { request: request },
        variables: variables
    )
   end

   describe  "PermissionGroup Duplicate Query Check" do
    let(:graphql_query) do
        <<~GRAPHQL
          query PermissionGroups {
              permissionGroups {
                groupName
                id
                permissions {
                  id
                  action
                  subject
              }
            }
          }
        GRAPHQL
      end
    let(:permissions) { all_privileges.map { |item| { "action"=>"#{item[0]}", "subject"=>"#{item[1]}" } }}
    it "will not produce a permission group set with duplicate permissions" do
      expect(subject["errors"]).to be_nil
      permission_sets = []
      subject["data"]["permissionGroups"].each do |permissionGroup|
        permissionGroup["permissions"].each do |permission|
          permission_sets.push(permission)
        end
      end
      puts "Permission Group Permissions [#{permission_sets.length}] All DB Permissions [#{permissions.length}]"
      expect(permission_sets.length).to eq(permissions.length)
    end
   end

end