# frozen_string_literal: true

require 'cht-lib-fabric/crns'
require 'cht-lib-fabric/contexts/request'
require 'cht-lib-fabric/tasks/actionable'
require 'role_management/helpers/flow_down_helper'

RSpec.describe ::RoleManagement::Helpers::FlowDownHelper do
  before(:each) do
    @flowdown = double('flowdown')
    allow(@flowdown).to receive(:enable_flow_down)
    allow(@flowdown).to receive(:flow_down_items)
    allow(@flowdown).to receive(:flow_down_items_by_org)
    Application.stub('clients.flowdown', @flowdown)
  end
  after(:each) do
    Application.unstub('clients.flowdown', @flowdown)
  end

  let(:request) do
    req = ::Platform::Contexts::Request.new
    req.client_ip = IPAddr.new('1.1.1.1')
    req.user_agent = 'Mozilla/4.0 WebTV/2.6 (compatible; MSIE 4.0)'
    req.current_customer = 2017
    req.current_organization = 893_353_197_629

    req
  end
  let(:id) do
    "crn:2017:role-document/1234"
  end

  let(:type) do
    "role-document"
  end

  let(:context) do
    ::Platform::Tasks::Actionable::Context.new({ request: request})
  end

  let(:metadata) do
    {"shared" => { "enabled" => true } }
  end
  describe 'enable_flow_down' do
    subject do
      described_class.new.enable_flow_down(id: id, context: context, metadata: metadata)
    end
    context 'when flow down service isnt available'
    it 'should still return a flowdown response' do
      allow(@flowdown).to receive(:enable_flow_down).and_raise
      expect(subject).to_not be_nil
      expect(subject[:items]).to_not be_nil
      expect(subject[:items].length).to eq(1)
      expect(subject[:items][0][:id]).to eq(id)
      expect(subject[:items][0][:enabled]).to be_truthy
    end
  end

  describe 'flow_down_items' do
    subject do
      described_class.new.get_flow_down_items type: type, context: context
    end
    context 'when flow down service isnt available'
    it 'should return an empty set of flow down items' do
      allow(@flowdown).to receive(:flow_down_items).and_raise
      expect(subject).to_not be_nil
      expect(subject).to be_a(Array)
      expect(subject.length).to eq(0)
    end
  end

  describe 'flow_down_items_by_org' do
    subject do
      described_class.new.get_flow_down_items_by_org type: type, context: context
    end
    context 'when flow down service isnt available'
    it 'should return an empty set of flow down items' do
      allow(@flowdown).to receive(:flow_down_items_by_org).and_raise
      expect(subject).to_not be_nil
      expect(subject).to be_a(Array)
      expect(subject.length).to eq(0)
    end
  end
end
