# frozen_string_literal: true

require 'role_management/messages/role_document'
require 'role_management/messages/role_binding'

RSpec.describe ::RoleManagement::Utils::EventPublish do
  include_context 'role_management'
  include_context 'request'
  include_context 'kafka'

  describe '#publish' do
    let(:ctx) { { request: request } }
    context 'when publishing an event for a role document' do
      it 'should call the publish method for CREATE without error' do
        expect { described_class.new.publish(role_document,
          ctx, ::RoleManagement::Messages::RoleDocument::CREATE) }.to_not raise_error
      end
      it 'should call the publish method for UPDATE without error' do
        expect { described_class.new.publish(role_document,
          ctx, ::RoleManagement::Messages::RoleDocument::UPDATE) }.to_not raise_error
      end
      it 'should call the publish method for DELETE without error' do
        expect { described_class.new.publish(role_document,
          ctx, ::RoleManagement::Messages::RoleDocument::DELETE) }.to_not raise_error
      end
    end
    context 'when publishing an event for a role binding' do
      it 'should call the publish method for CREATE without error' do
        expect{ described_class.new.publish(role_binding,
          ctx, ::RoleManagement::Messages::RoleBinding::CREATE) }.to_not raise_error
      end
      it 'should call the publish method for UPDATE without error' do
        expect{ described_class.new.publish(role_binding,
          ctx, ::RoleManagement::Messages::RoleBinding::UPDATE) }.to_not raise_error
      end
      it 'should call the publish method for DELETE without error' do
        expect{ described_class.new.publish(role_binding,
          ctx, ::RoleManagement::Messages::RoleBinding::DELETE) }.to_not raise_error
      end
    end
  end
end
